# almabtrieb

An implementation of the Cattle Drive protocol. It is able to connect to a message broker both through AMQP and MQTT.

## Installation

For amqp, e.g. RabbitMQ

```bash
pip install almabtrieb[amqp]
```

For mqtt and mqtt over websockets

```bash
pip install almabtrieb[mqtt]   
```
